==> agr-center-domain-3.1.0-CLOUD-DEV-20230808.073749-46-sources.jar: com/tydic/dyc/agr/model/agr/AgrAgrDo.java <==
package com.tydic.dyc.agr.model.agr;

import com.tydic.dyc.agr.model.agr.sub.*;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-08-04 17:46
 **/
@Data
public class AgrAgrDo implements Serializable {
	private static final long serialVersionUID =  6357011406368784335L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细
	 */
	private List<AgrItem> agrItem;
	/**
	 * 协议应用范围
	 */
	private List<AgrAppScope> agrAppScope;
	/**
	 * 协议支付配置
	 */
	private List<AgrPayConfig> agrPayConfig;
	/**
	 * 协议调价配置
	 */
	private AgrAdjustCfg agrAdjustCfg;
	/**
	 * 协议类目范围
	 */
	private List<AgrCataScope> agrCataScope;
	/**
	 * 协议外部关联
	 */
	private List<AgrRel> agrRel;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExt> agrMainExt;
	/**
	 * 协议主体附件
	 */
	private List<AgrAccessory> agrAccessory;
	/**
	 * 租户ID
	 */
	private Long tenantId;
	/**
	 * 用户ID
	 */
	private Long userId;
	/**
	 * 用户账号
	 */
	private String username;
	/**
	 * 机构ID
	 */
	private Long orgId;
	/**
	 * 机构名称
	 */
	private String orgName;
	/**
	 * 操作时间
	 */
	private Date operTime;
	/**
	 * 用户名称
	 */
	private String name;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 创建时间
	 */
	private Date createTime;
	/**
	 * 分配记录
	 */
	private List<AgrAllocateRecord> agrAllocateRecord;
	/**
	 * 机构树路径
	 */
	private String orgPath;
	/**
	 * 确认时间
	 */
	private Date confirmTime;
	/**
	 * 确认人
	 */
	private String confirmName;
	/**
	 * 协议版本记录
	 */
	private List<AgrAgrVersion> agrAgrVersion;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 修改范围
	 */
	private Integer updateRange;
	/**
	 * 创建人id
	 */
	private Long createLoginId;
	/**
	 * 创建人名称
	 */
	private String createName;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-domain-3.2.2-CLOUD-DEV-20250311.085359-5-sources.jar: com/tydic/dyc/agr/model/agr/AgrAgrDo.java <==
package com.tydic.dyc.agr.model.agr;

import com.tydic.dyc.agr.model.agr.sub.*;
import com.tydic.dyc.agr.service.agr.bo.AgrItemPriceExecutionBo;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-08-04 17:46
 **/
@Data
public class AgrAgrDo implements Serializable {
	private static final long serialVersionUID =  6357011406368784335L;

	/**
	 * 协议ID
	 */
	private Long agrId;
	/**
	 * 外部关联编号
	 */
	private String relCode;
	/**
	 * 企业协议编号
	 */
	private String enAgrCode;
	/**
	 * 协议名称
	 */
	private String agrName;
	/**
	 * 协议模式
	 */
	private Integer agrMode;
	/**
	 * 协议分类
	 */
	private Integer agrType;
	/**
	 * 协议状态
	 */
	private Integer agrStatus;
	/**
	 * 协议价格类型
	 */
	private Integer agrPriceType;
	/**
	 * 协议类别名称
	 */
	private String agrCategoryName;
	/**
	 * 协议类别id
	 */
	private Long agrCategoryId;
	/**
	 * 协议来源
	 */
	private Integer agrSrc;
	/**
	 * 协议来源名称
	 */
	private String agrSrcName;
	/**
	 * 协议来源编码
	 */
	private String agrSrcCode;
	/**
	 * 交易模式
	 */
	private Integer tradeMode;
	/**
	 * 铺货方式
	 */
	private Integer vendorMode;
	/**
	 * 是否配送
	 */
	private Integer whetherDispatch;
	/**
	 * 是否分配
	 */
	private Integer whetherAssign;
	/**
	 * 协议生效日期
	 */
	private Date effDate;
	/**
	 * 协议失效日期
	 */
	private Date expDate;
	/**
	 * 标的物名称
	 */
	private String matterName;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 管理单位名称
	 */
	private String managementOrgName;
	/**
	 * 采购单位ID
	 */
	private Long purchaseOrgId;
	/**
	 * 采购单位名称
	 */
	private String purchaseOrgName;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货商联系人
	 */
	private String supplierContact;
	/**
	 * 供货商联系电话
	 */
	private String supplierPhone;
	/**
	 * 结算单位ID
	 */
	private Long settlementOrgId;
	/**
	 * 结算单位名称
	 */
	private String settlementOrgName;
	/**
	 * 采购类别
	 */
	private Integer agreementVariety;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 质保期单位
	 */
	private String quaprotectUnit;
	/**
	 * 质保期时间
	 */
	private String quaprotectCount;
	/**
	 * 质保期(月)
	 */
	private Integer warantty;
	/**
	 * 所属专区
	 */
	private Integer agrLocation;
	/**
	 * 是否商城铺货标识
	 */
	private Integer whetherStorePlan;
	/**
	 * 应用范围类型
	 */
	private Integer scopeType;
	/**
	 * 调价机制
	 */
	private Integer adjustPrice;
	/**
	 * 组织名称
	 */
	private String agrOrgName;
	/**
	 * 其他付款条件
	 */
	private String payCase;
	/**
	 * 协议签订时间
	 */
	private Date agrSignTime;
	/**
	 * 经办人ID
	 */
	private Long agrOperatorId;
	/**
	 * 经办人名称
	 */
	private String agrOperatorName;
	/**
	 * 经办人用户名
	 */
	private String agrOperatorUsername;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细
	 */
	private List<AgrItem> agrItem;
	/**
	 * 协议应用范围
	 */
	private List<AgrAppScope> agrAppScope;
	/**
	 * 协议支付配置
	 */
	private List<AgrPayConfig> agrPayConfig;
	/**
	 * 协议调价配置
	 */
	private AgrAdjustCfg agrAdjustCfg;
	/**
	 * 协议类目范围
	 */
	private List<AgrCataScope> agrCataScope;
	/**
	 * 协议外部关联
	 */
	private List<AgrRel> agrRel;
	/**
	 * 协议主体拓展
	 */
	private List<AgrMainExt> agrMainExtBOs;
	/**
	 * 协议主体附件
	 */
	private List<AgrAccessory> agrAccessory;
	/**
	 * 租户ID
	 */
	private Long tenantId;
	/**
	 * 用户ID
	 */
	private Long userId;
	/**
	 * 用户账号
	 */
	private String username;
	/**
	 * 机构ID
	 */
	private Long orgId;
	/**
	 * 机构名称
	 */
	private String orgName;
	/**
	 * 操作时间
	 */
	private Date operTime;
	/**
	 * 用户名称
	 */
	private String name;
	/**
	 * 协议编号
	 */
	private String agrCode;
	/**
	 * 协议版本
	 */
	private String agrVersion;
	/**
	 * 创建时间
	 */
	private Date createTime;
	/**
	 * 分配记录
	 */
	private List<AgrAllocateRecord> agrAllocateRecord;
	/**
	 * 机构树路径
	 */
	private String orgPath;
	/**
	 * 确认时间
	 */
	private Date confirmTime;
	/**
	 * 确认人
	 */
	private String confirmName;
	/**
	 * 协议版本记录
	 */
	private List<AgrAgrVersion> agrAgrVersion;
	/**
	 * 是否有明细标识
	 */
	private Integer whetherHaveItem;
	/**
	 * 修改范围
	 */
	private Integer updateRange;
	/**
	 * 创建人id
	 */
	private Long createLoginId;
	/**
	 * 创建人名称
	 */
	private String createName;
	/**
	 * 含税金额
	 */
	private BigDecimal taxAmount;
	/**
	 * 税率
	 */
	private String taxRate;
	/**
	 * 编制人联系方式
	 */
	private String createNameContact;
	/**
	 * 签约方数量
	 */
	private String signatoryNum;
	/**
	 * 扩展字段1
	 */
	private String agrMainExtend1;
	/**
	 * 扩展字段2
	 */
	private String agrMainExtend2;
	/**
	 * 扩展字段3
	 */
	private String agrMainExtend3;
	/**
	 * 扩展字段4
	 */
	private String agrMainExtend4;
	/**
	 * 扩展字段5
	 */
	private String agrMainExtend5;
	/**
	 * 扩展字段6
	 */
	private String agrMainExtend6;
	/**
	 * 扩展字段7
	 */
	private String agrMainExtend7;
	/**
	 * 扩展字段8
	 */
	private String agrMainExtend8;
	/**
	 * 扩展字段9
	 */
	private String agrMainExtend9;
	/**
	 * 扩展json
	 */
	private String agrMainExtendJson;
	/**
	 * 父协议ID
	 */
	private Long parentAgrId;
	/**
	 * 编制人单位名称
	 */
	private String createOrgName;
	/**
	 * 编制人单位ID
	 */
	private Long createOrgId;
	/**
	 * 外部关联ID
	 */
	private String relId;
	/**
	 * 外部关联名称
	 */
	private String relName;
	/**
	 * 协议来源ID
	 */
	private String agrSrcId;
	/**
	 * 不含税金额
	 */
	private BigDecimal noTaxAmount;
	/**
	 * 更新者ID
	 */
	private Long updateLoginId;
	/**
	 * 更新人
	 */
	private String updateName;
	/**
	 * 更新人用户名
	 */
	private String updateUsername;
	/**
	 * 排序
	 */
	private String orderBy;

	/**
	 * 执行方式
	 */
	private String executionMethod;
	/**
	 * 采购单净总价（元）
	 */
	private BigDecimal totalPrice;
	/**
	 * 付款方式
	 */
	private String payMethodDesc;
	/**
	 * 协议主体扩展表字段编码集合
	 */
	private List<String> fieldCodeList;
	/**
	 * 服务费比例（%）
	 */
	private String servFee;
	/**
	 * 采购类型 1集采2自采
	 */
	private Integer purType;
	/**
	 * 协议编制单位id集合
	 */
	private String createCompanyIds;
	/**
	 * 协议编制单位名称集合
	 */
	private String createCompanyNames;
	/**
	 * 协议编制单位机构树集合
	 */
	private String createOrgTreePaths;
	/**
	 * 协议终止时间
	 */
	private Date terminationDate;
	/**
	 * 协议终止原因
	 */
	private String terminationReason;
	/**
	 * 是否需要预警
	 */
	private Integer isNeedWarn;
	/**
	 * 自建协议业务类型：1.企业采购 2.员工超市
	 */
	private Integer agrBusinessType;
}
